Place
=====

.. currentmodule:: wwt_data_formats.place

.. autoclass:: Place
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Place.angle
      ~Place.angular_size
      ~Place.annotation
      ~Place.background_image_set
      ~Place.classification
      ~Place.constellation
      ~Place.cross_validation_lock
      ~Place.data_set_type
      ~Place.dec_deg
      ~Place.description
      ~Place.distance
      ~Place.dome_alt
      ~Place.dome_az
      ~Place.foreground_image_set
      ~Place.image_set
      ~Place.latitude
      ~Place.longitude
      ~Place.magnitude
      ~Place.msr_community_id
      ~Place.msr_component_id
      ~Place.name
      ~Place.opacity
      ~Place.permission
      ~Place.ra_hr
      ~Place.rmeta
      ~Place.rotation_deg
      ~Place.thumbnail
      ~Place.xmeta
      ~Place.zoom_level

   .. rubric:: Methods Summary

   .. autosummary::

      ~Place.add_traits
      ~Place.apply_to_xml
      ~Place.as_imageset
      ~Place.class_own_trait_events
      ~Place.class_own_traits
      ~Place.class_trait_names
      ~Place.class_traits
      ~Place.from_file
      ~Place.from_text
      ~Place.from_url
      ~Place.from_xml
      ~Place.has_trait
      ~Place.hold_trait_notifications
      ~Place.mutate_urls
      ~Place.notify_change
      ~Place.observe
      ~Place.on_trait_change
      ~Place.set_trait
      ~Place.setup_instance
      ~Place.to_xml
      ~Place.to_xml_string
      ~Place.trait_defaults
      ~Place.trait_events
      ~Place.trait_has_value
      ~Place.trait_metadata
      ~Place.trait_names
      ~Place.trait_values
      ~Place.traits
      ~Place.unobserve
      ~Place.unobserve_all
      ~Place.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: angle
   .. autoattribute:: angular_size
   .. autoattribute:: annotation
   .. autoattribute:: background_image_set
   .. autoattribute:: classification
   .. autoattribute:: constellation
   .. autoattribute:: cross_validation_lock
   .. autoattribute:: data_set_type
   .. autoattribute:: dec_deg
   .. autoattribute:: description
   .. autoattribute:: distance
   .. autoattribute:: dome_alt
   .. autoattribute:: dome_az
   .. autoattribute:: foreground_image_set
   .. autoattribute:: image_set
   .. autoattribute:: latitude
   .. autoattribute:: longitude
   .. autoattribute:: magnitude
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: opacity
   .. autoattribute:: permission
   .. autoattribute:: ra_hr
   .. autoattribute:: rmeta
   .. autoattribute:: rotation_deg
   .. autoattribute:: thumbnail
   .. autoattribute:: xmeta
   .. autoattribute:: zoom_level

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: as_imageset
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: mutate_urls
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: write_xml
